package com.fossgalaxy.games.ggj2017;

import java.awt.BasicStroke;
import java.awt.Color;
import java.awt.Graphics2D;
import java.awt.Shape;
import java.awt.Stroke;
import java.awt.geom.Area;
import java.util.Collection;
import java.util.List;

import org.codetome.hexameter.core.api.CubeCoordinate;
import org.codetome.hexameter.core.api.Hexagon;

import com.fossgalaxy.games.rts.GameState;
import com.fossgalaxy.games.rts.entity.Entity;
import com.fossgalaxy.games.rts.entity.HexagonTile;
import com.fossgalaxy.games.rts.order.AttackOrderRanged;
import com.fossgalaxy.games.rts.order.MoveOrder;
import com.fossgalaxy.games.rts.order.Order;
import com.fossgalaxy.games.rts.ui.GameAction;
import com.fossgalaxy.games.rts.ui.GameView;

public class RangeAttackAction implements GameAction {
	private final Color HINT_ATTACK_COLOUR = new Color(229, 5, 26, 50);
	private final Stroke HINT_STROKE = new BasicStroke(2f);
	
	@Override
	public void renderHints(Graphics2D g, GameState s, Entity actor) {
		if (actor == null) {
			return;
		}
		
		Collection<Hexagon<HexagonTile>> range = s.getRange(actor.getPos(), actor.getType().getAttackRange());
		System.out.println(range);
		
		Area area = new Area();
		
		range.forEach(h -> {
	        Entity e = s.getEntityAt(h.getCubeCoordinate());
	        if (e == null) {
	        	return;
	        }
	        
	        //don't attack friendlies - it's rude
	        if (e.getOwner() == actor.getOwner()) {
	        	return;
	        }
	        
		    Shape hexShape = GameView.hex2shape.apply(h);
	        
	        area.add(new Area(hexShape));
	        
	        g.setColor(HINT_ATTACK_COLOUR);
	        g.fill(hexShape);
	        
	        g.setColor(Color.RED);
	        g.setStroke(HINT_STROKE);
	        g.draw(hexShape);
		});
		
	}

	@Override
	public Order generateOrder(CubeCoordinate co, GameState s) {
		Entity e = s.getEntityAt(co);
		if (e == null) {
			return null;
		}
		
		return new AttackOrderRanged(e);
	}
}
